__builtin__.unicode

Module __builtin__ :: Class unicode |
[show private | hide private]
[frames | no frames]

## Type unicode

    object --+
             |
    basestring --+
                 |
                unicode

Known Subclasses:
  `Special`

unicode(string [, encoding[, errors]]) -> object

Create a new Unicode object from the given encoded string. encoding defaults to the current default string encoding. errors can be 'strict', 'replace' or 'ignore' and defaults to 'strict'.

Method Summary
| ``__add__`(x, y)` x.__add__(y) <==> x+y
| ``__cmp__`(x, y)` x.__cmp__(y) <==> cmp(x,y)
| ``__contains__`(x, y)` x.__contains__(y) <==> y in x
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__getitem__`(x, y)` x.__getitem__(y) <==> x[y]
| `__getnewargs__(...)`
| ``__getslice__`(x, i, j)` Use of negative indices is not supported.
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__len__`(x)` x.__len__() <==> len(x)
| ``__mod__`(x, y)` x.__mod__(y) <==> x%y
| ``__mul__`(x, n)` x.__mul__(n) <==> x*n
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__rmod__`(x, y)` x.__rmod__(y) <==> y%x
| ``__rmul__`(x, n)` x.__rmul__(n) <==> n*x
| ``__str__`(x)` x.__str__() <==> str(x)
| ``capitalize`(S)` Return a capitalized version of S, i.e.
| ``center`(S, width, fillchar)` Return S centered in a Unicode string of length width.
| ``count`(S, sub, start, end)` Return the number of occurrences of substring sub in Unicode string S[start:end].
| ``decode`(S, encoding, errors)` Decodes S using the codec registered for encoding.
| ``encode`(S, encoding, errors)` Encodes S using the codec registered for encoding.
| ``endswith`(S, suffix, start, end)` Return True if S ends with the specified suffix, False otherwise.
| ``expandtabs`(S, tabsize)` Return a copy of S where all tab characters are expanded using spaces.
| ``find`(S, sub, start, end)` Return the lowest index in S where substring sub is found, such that sub is contained within s[start,end].
| ``index`(S, sub, start, end)` Like S.find() but raise ValueError when the substring is not found.
| ``isalnum`(S)` Return True if all characters in S are alphanumeric and there is at least one character in S, False otherwise.
| ``isalpha`(S)` Return True if all characters in S are alphabetic and there is at least one character in S, False otherwise.
| ``isdecimal`(S)` Return True if there are only decimal characters in S, False otherwise.
| ``isdigit`(S)` Return True if all characters in S are digits and there is at least one character in S, False otherwise.
| ``islower`(S)` Return True if all cased characters in S are lowercase and there is at least one cased character in S, False otherwise.
| ``isnumeric`(S)` Return True if there are only numeric characters in S, False otherwise.
| ``isspace`(S)` Return True if all characters in S are whitespace and there is at least one character in S, False otherwise.
| ``istitle`(S)` Return True if S is a titlecased string and there is at least one character in S, i.e.
| ``isupper`(S)` Return True if all cased characters in S are uppercase and there is at least one cased character in S, False otherwise.
| ``join`(S, sequence)` Return a string which is the concatenation of the strings in the sequence.
| ``ljust`(S, width, fillchar)` Return S left justified in a Unicode string of length width.
| ``lower`(S)` Return a copy of the string S converted to lowercase.
| ``lstrip`(S, chars)` Return a copy of the string S with leading whitespace removed.
| ``replace`(...)` S.replace (old, new[, maxsplit]) -> unicode
| ``rfind`(S, sub, start, end)` Return the highest index in S where substring sub is found, such that sub is contained within s[start,end].
| ``rindex`(S, sub, start, end)` Like S.rfind() but raise ValueError when the substring is not found.
| ``rjust`(S, width, fillchar)` Return S right justified in a Unicode string of length width.
| ``rsplit`(S, sep, maxsplit)` Return a list of the words in S, using sep as the delimiter string, starting at the end of the string and working to the front.
| ``rstrip`(S, chars)` Return a copy of the string S with trailing whitespace removed.
| ``split`(S, sep, maxsplit)` Return a list of the words in S, using sep as the delimiter string.
| ``splitlines`(...)` S.splitlines([keepends]]) -> list of strings
| ``startswith`(S, prefix, start, end)` Return True if S starts with the specified prefix, False otherwise.
| ``strip`(S, chars)` Return a copy of the string S with leading and trailing whitespace removed.
| ``swapcase`(S)` Return a copy of S with uppercase characters converted to lowercase and vice versa.
| ``title`(S)` Return a titlecased version of S, i.e.
| ``translate`(S, table)` Return a copy of the string S, where all characters have been mapped through the given translation table, which must be a mapping of Unicode ordinals to Unicode ordinals, Unicode strings or None.
| ``upper`(S)` Return a copy of S converted to uppercase.
| ``zfill`(S, width)` Pad a numeric string x with zeros on the left, to fill a field of the specified width.
Inherited from object
| ``__init__`(...)` x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value

Method Details

    ### __add__(x, y) (Addition operator) x.__add__(y) <==> x+y Returns:
        x+y

    ### __cmp__(x, y) (Comparison operator) x.__cmp__(y) <==> cmp(x,y) Returns:
        cmp(x,y)

    ### __contains__(x, y) (In operator) x.__contains__(y) <==> y in x Returns:
        y in x

### __getattribute__(...) x.__getattribute__('name') <==> x.name Overrides: `__builtin__.object.__getattribute__`

    ### __getitem__(x, y) (Indexing operator) x.__getitem__(y) <==> x[y] Returns:
        x[y]

    ### __getslice__(x, i, j) (Slicling operator) Use of negative indices is not supported. Returns:
        x[i:j]

    ### __hash__(x) (Hashing function) x.__hash__() <==> hash(x) Returns:
        hash(x)
Overrides: `__builtin__.object.__hash__`

    ### __len__(x) (Length operator) x.__len__() <==> len(x) Returns:
        len(x)

    ### __mod__(x, y) x.__mod__(y) <==> x%y Returns:
        x%y

    ### __mul__(x, n) x.__mul__(n) <==> x*n Returns:
        x*n

    ### __new__(T, S, ...) T.__new__(S, ...) -> a new object with type S, a subtype of T Returns:
        a new object with type S, a subtype of T
Overrides: `__builtin__.basestring.__new__`

    ### __repr__(x) (Representation operator) x.__repr__() <==> repr(x) Returns:
        repr(x)
Overrides: `__builtin__.object.__repr__`

    ### __rmod__(x, y) x.__rmod__(y) <==> y%x Returns:
        y%x

    ### __rmul__(x, n) x.__rmul__(n) <==> n*x Returns:
        n*x

    ### __str__(x) (Informal representation operator) x.__str__() <==> str(x) Returns:
        str(x)
Overrides: `__builtin__.object.__str__`

    ### capitalize(S) Return a capitalized version of S, i.e. make the first character have upper case. Returns:
        unicode

    ### center(S, width, fillchar=...) Return S centered in a Unicode string of length width. Padding is done using the specified fill character (default is a space) Returns:
        unicode

    ### count(S, sub, start=..., end=...) Return the number of occurrences of substring sub in Unicode string S[start:end]. Optional arguments start and end are interpreted as in slice notation. Returns:
        int

    ### decode(S, encoding=..., errors=...) Decodes S using the codec registered for encoding. encoding defaults to the default encoding. errors may be given to set a different error handling scheme. Default is 'strict' meaning that encoding errors raise a UnicodeDecodeError. Other possible values are 'ignore' and 'replace' as well as any other name registerd with codecs.register_error that is able to handle UnicodeDecodeErrors. Returns:
        string or unicode

    ### encode(S, encoding=..., errors=...) Encodes S using the codec registered for encoding. encoding defaults to the default encoding. errors may be given to set a different error handling scheme. Default is 'strict' meaning that encoding errors raise a UnicodeEncodeError. Other possible values are 'ignore', 'replace' and 'xmlcharrefreplace' as well as any other name registered with codecs.register_error that can handle UnicodeEncodeErrors. Returns:
        string or unicode

    ### endswith(S, suffix, start=..., end=...) Return True if S ends with the specified suffix, False otherwise. With optional start, test S beginning at that position. With optional end, stop comparing S at that position. Returns:
        bool

    ### expandtabs(S, tabsize=...) Return a copy of S where all tab characters are expanded using spaces. If tabsize is not given, a tab size of 8 characters is assumed. Returns:
        unicode

    ### find(S, sub, start=... , end=...) Return the lowest index in S where substring sub is found, such that sub is contained within s[start,end]. Optional arguments start and end are interpreted as in slice notation. Return -1 on failure. Returns:
        int

    ### index(S, sub, start=... , end=...) Like S.find() but raise ValueError when the substring is not found. Returns:
        int

    ### isalnum(S) Return True if all characters in S are alphanumeric and there is at least one character in S, False otherwise. Returns:
        bool

    ### isalpha(S) Return True if all characters in S are alphabetic and there is at least one character in S, False otherwise. Returns:
        bool

    ### isdecimal(S) Return True if there are only decimal characters in S, False otherwise. Returns:
        bool

    ### isdigit(S) Return True if all characters in S are digits and there is at least one character in S, False otherwise. Returns:
        bool

    ### islower(S) Return True if all cased characters in S are lowercase and there is at least one cased character in S, False otherwise. Returns:
        bool

    ### isnumeric(S) Return True if there are only numeric characters in S, False otherwise. Returns:
        bool

    ### isspace(S) Return True if all characters in S are whitespace and there is at least one character in S, False otherwise. Returns:
        bool

    ### istitle(S) Return True if S is a titlecased string and there is at least one character in S, i.e. upper- and titlecase characters may only follow uncased characters and lowercase characters only cased ones. Return False otherwise. Returns:
        bool

    ### isupper(S) Return True if all cased characters in S are uppercase and there is at least one cased character in S, False otherwise. Returns:
        bool

    ### join(S, sequence) Return a string which is the concatenation of the strings in the sequence. The separator between elements is S. Returns:
        unicode

    ### ljust(S, width, fillchar=...) Return S left justified in a Unicode string of length width. Padding is done using the specified fill character (default is a space). Returns:
        int

    ### lower(S) Return a copy of the string S converted to lowercase. Returns:
        unicode

    ### lstrip(S, chars=...) Return a copy of the string S with leading whitespace removed. If chars is given and not None, remove characters in chars instead. If chars is a str, it will be converted to unicode before stripping Returns:
        unicode

### replace(...) S.replace (old, new[, maxsplit]) -> unicode Return a copy of S with all occurrences of substring old replaced by new. If the optional argument maxsplit is given, only the first maxsplit occurrences are replaced.

    ### rfind(S, sub, start=... , end=...) Return the highest index in S where substring sub is found, such that sub is contained within s[start,end]. Optional arguments start and end are interpreted as in slice notation. Return -1 on failure. Returns:
        int

    ### rindex(S, sub, start=... , end=...) Like S.rfind() but raise ValueError when the substring is not found. Returns:
        int

    ### rjust(S, width, fillchar=...) Return S right justified in a Unicode string of length width. Padding is done using the specified fill character (default is a space). Returns:
        unicode

    ### rsplit(S, sep=... , maxsplit=...) Return a list of the words in S, using sep as the delimiter string, starting at the end of the string and working to the front. If maxsplit is given, at most maxsplit splits are done. If sep is not specified, any whitespace string is a separator. Returns:
        list of strings

    ### rstrip(S, chars=...) Return a copy of the string S with trailing whitespace removed. If chars is given and not None, remove characters in chars instead. If chars is a str, it will be converted to unicode before stripping Returns:
        unicode

    ### split(S, sep=... , maxsplit=...) Return a list of the words in S, using sep as the delimiter string. If maxsplit is given, at most maxsplit splits are done. If sep is not specified or is None, any whitespace string is a separator. Returns:
        list of strings

### splitlines(...) S.splitlines([keepends]]) -> list of strings Return a list of the lines in S, breaking at line boundaries. Line breaks are not included in the resulting list unless keepends is given and true.

    ### startswith(S, prefix, start=..., end=...) Return True if S starts with the specified prefix, False otherwise. With optional start, test S beginning at that position. With optional end, stop comparing S at that position. Returns:
        bool

    ### strip(S, chars=...) Return a copy of the string S with leading and trailing whitespace removed. If chars is given and not None, remove characters in chars instead. If chars is a str, it will be converted to unicode before stripping Returns:
        unicode

    ### swapcase(S) Return a copy of S with uppercase characters converted to lowercase and vice versa. Returns:
        unicode

    ### title(S) Return a titlecased version of S, i.e. words start with title case characters, all remaining cased characters have lower case. Returns:
        unicode

    ### translate(S, table) Return a copy of the string S, where all characters have been mapped through the given translation table, which must be a mapping of Unicode ordinals to Unicode ordinals, Unicode strings or None. Unmapped characters are left untouched. Characters mapped to None are deleted. Returns:
        unicode

    ### upper(S) Return a copy of S converted to uppercase. Returns:
        unicode

    ### zfill(S, width) Pad a numeric string x with zeros on the left, to fill a field of the specified width. The string x is never truncated. Returns:
        unicode

Generated by Epydoc 2.1 on Sat Sep 30 00:54:37 2006 | http://epydoc.sf.net